@@ -11,7 +11,7 @@ require Exporter;
 use POSIX qw(floor);
 use 5.008;    #5.8.0
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 @ISA     = qw(Exporter);
 
 @EXPORT_OK = qw(
@@ -173,10 +173,24 @@ sub calculate_month {
 
 __END__
 
+=pod
+
+=begin markdown
+
+[![CPAN version](https://badge.fury.io/pl/Date-Pregnancy.svg)](http://badge.fury.io/pl/Date-Pregnancy)
+[![Build Status](https://travis-ci.org/jonasbn/Date-Pregnancy.svg?branch=master)](https://travis-ci.org/jonasbn/Date-Pregnancy)
+[![Coverage Status](https://coveralls.io/repos/jonasbn/Date-Pregnancy/badge.png)](https://coveralls.io/r/jonasbn/Date-Pregnancy)
+
+=end markdown
+
 =head1 NAME
 
 Date::Pregnancy - calculate birthdate and week numbers for a pregnancy
 
+=head1 VERSION
+
+This documentation describes version 0.05
+
 =head1 SYNOPSIS
 
 	use Date::Pregnancy qw(calculate_birthday);
@@ -464,12 +478,8 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Date-Pregnancy is (C) by Jonas B. Nielsen, (jonasbn) 2004
+Date-Pregnancy is (C) by Jonas B. Nielsen, (jonasbn) 2004-2015
 
-Date-Pregnancy is released under the artistic license
-
-The distribution is licensed under the Artistic License, as specified
-by the Artistic file in the standard perl distribution
-(http://www.perl.com/language/misc/Artistic.html).
+Date-Pregnancy is released under the artistic license 2.0
 
 =cut
